@@ -20,12 +20,22 @@ def approve_tests(polarion_project_id: str, added_ids: list[str]) -> dict[str, l
 
 
 def remove_approved_tests(
-    polarion_project_id: str, branch: str, added_ids: list[str] | None = None
+    polarion_project_id: str,
+    branch: str | None = None,
+    previous_commit: str | None = None,
+    current_commit: str | None = None,
+    added_ids: list[str] | None = None,
 ) -> dict[str, list[str]]:
     removed_polarions = {}
     added_ids = added_ids or []
     if removed_ids := set(
-        find_polarion_ids(polarion_project_id=polarion_project_id, string_to_match="removed", branch=branch)
+        find_polarion_ids(
+            polarion_project_id=polarion_project_id,
+            string_to_match="removed",
+            branch=branch,
+            previous_commit=previous_commit,
+            current_commit=current_commit,
+        )
     ) - set(added_ids):
         LOGGER.info(f"Following polarion ids were removed: {removed_ids}")
         removed_polarions = update_polarion_ids(
@@ -43,9 +53,12 @@ def remove_approved_tests(
     default=os.path.expanduser("~/.config/python-utility-scripts/config.yaml"),
 )
 @click.option("--project-id", "-p", help="Provide the polarion project id")
-@click.option("--branch", "-b", help="Provide the github remote branch to run against", default="origin/main")
+@click.option("--previous-commit", "-p", help="Provide previous-commit to compare against", required=True)
+@click.option("--current-commit", "-c", help="Provide current-commit to compare with", required=True)
 @click.option("--verbose", default=False, is_flag=True)
-def polarion_approve_automate(config_file_path: str, project_id: str, branch: str, verbose: bool) -> None:
+def polarion_approve_automate(
+    config_file_path: str, project_id: str, previous_commit: str, current_commit: str, verbose: bool
+) -> None:
     if verbose:
         LOGGER.setLevel(logging.DEBUG)
         # since the utilities are in apps.polarion.polarion_utils, we need to change log level
@@ -56,12 +69,21 @@ def polarion_approve_automate(config_file_path: str, project_id: str, branch: st
         config_file_path=config_file_path, util_name="pyutils-polarion-set-automated"
     )
     added_polarions = {}
-    if added_ids := find_polarion_ids(polarion_project_id=polarion_project_id, string_to_match="added", branch=branch):
+    if added_ids := find_polarion_ids(
+        polarion_project_id=polarion_project_id,
+        string_to_match="added",
+        branch=None,
+        previous_commit=previous_commit,
+        current_commit=current_commit,
+    ):
         added_polarions = approve_tests(polarion_project_id=polarion_project_id, added_ids=added_ids)
         LOGGER.debug(f"Following polarion ids were marked automated and approved: {added_polarions.get('updated')}")
 
     removed_polarions = remove_approved_tests(
-        polarion_project_id=polarion_project_id, added_ids=added_ids, branch=branch
+        polarion_project_id=polarion_project_id,
+        added_ids=added_ids,
+        previous_commit=previous_commit,
+        current_commit=current_commit,
     )
     if removed_polarions.get("failed") or added_polarions.get("failed"):
         error = "Following polarion ids updates failed."
